
# Type: local_name_value


a name assigned to an element in a given ontology

URI: [meta:local_name_value](https://w3id.org/biolink/biolinkml/meta/local_name_value)


## Domain and Range

[LocalName](LocalName.md) ->  <sub>REQ</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [LocalName](LocalName.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | skos:altLabel |

